@@ -10,7 +10,7 @@
 # Modules and declarations
 ##############################################################################
 
-package App::DocKnot::Command 3.05;
+package App::DocKnot::Command 4.01;
 
 use 5.024;
 use autodie;
@@ -18,7 +18,9 @@ use warnings;
 
 use App::DocKnot::Dist;
 use App::DocKnot::Generate;
+use App::DocKnot::Update;
 use Getopt::Long;
+use Pod::Usage qw(pod2usage);
 
 # Defines the subcommands, their options, and the module and method that
 # implements them.  The keys are the names of the commands.  Each value is a
@@ -55,11 +57,10 @@ use Getopt::Long;
 #     are not set, an error will be thrown.
 our %COMMANDS = (
     dist => {
-        method   => 'make_distribution',
-        module   => 'App::DocKnot::Dist',
-        options  => ['distdir|d=s', 'metadata|m=s'],
-        maximum  => 0,
-        required => ['distdir'],
+        method  => 'make_distribution',
+        module  => 'App::DocKnot::Dist',
+        options => ['distdir|d=s', 'metadata|m=s', 'pgp-key|p=s'],
+        maximum => 0,
     },
     generate => {
         method  => 'generate_output',
@@ -74,6 +75,12 @@ our %COMMANDS = (
         options => ['metadata|m=s', 'width|w=i'],
         maximum => 0,
     },
+    update => {
+        method  => 'update',
+        module  => 'App::DocKnot::Update',
+        options => ['metadata|m=s', 'output|o=s'],
+        maximum => 0,
+    },
 );
 
 ##############################################################################
@@ -82,7 +89,6 @@ our %COMMANDS = (
 
 # Parse command-line options and do any required error handling.
 #
-# $self        - The App::DocKnot::Command object
 # $command     - The command being run or undef for top-level options
 # $options_ref - A reference to the options specification
 # @args        - The arguments to the command
@@ -123,7 +129,6 @@ sub _parse_options {
 
 # Parse command-line options for a given command.
 #
-# $self    - The App::DocKnot::Command object
 # $command - The command being run
 # @args    - The arguments to the command
 #
@@ -143,8 +148,6 @@ sub _parse_command {
 
 # Create a new App::DocKnot::Command object.
 #
-# $class - Class of object to create
-#
 # Returns: Newly created object
 sub new {
     my ($class) = @_;
@@ -156,7 +159,6 @@ sub new {
 # Parse command-line options to determine which command to run, and then
 # dispatch that command.
 #
-# $self - The App::DocKnot::Command object
 # @args - Command-line arguments (optional, default: @ARGV)
 #
 # Returns: undef
@@ -206,13 +208,9 @@ sub run {
 
     # Dispatch the command and turn exceptions into error messages.
     eval {
-        if ($COMMANDS{$command}{code}) {
-            $COMMANDS{$command}{code}->($opts_ref, $args_ref->@*);
-        } else {
-            my $object = $COMMANDS{$command}{module}->new($opts_ref);
-            my $method = $COMMANDS{$command}{method};
-            $object->$method($args_ref->@*);
-        }
+        my $object = $COMMANDS{$command}{module}->new($opts_ref);
+        my $method = $COMMANDS{$command}{method};
+        $object->$method($args_ref->@*);
     };
     if ($@) {
         my $error = $@;
@@ -231,7 +229,8 @@ sub run {
 __END__
 
 =for stopwords
-Allbery DocKnot docknot MERCHANTABILITY NONINFRINGEMENT sublicense
+Allbery DocKnot docknot MERCHANTABILITY NONINFRINGEMENT sublicense Kwalify
+IO-Compress-Lzma
 
 =head1 NAME
 
@@ -244,9 +243,11 @@ App::DocKnot::Command - Run DocKnot commands
 
 =head1 REQUIREMENTS
 
-Perl 5.24 or later and the modules File::BaseDir, File::ShareDir, JSON,
-Perl6::Slurp, and Template (part of Template Toolkit), all of which are
-available from CPAN.
+Perl 5.24 or later and the modules File::BaseDir, File::ShareDir,
+IO::Compress::Xz (part of IO-Compress-Lzma), IO::Uncompress::Gunzip (part of
+IO-Compress), IPC::Run, IPC::System::Simple, JSON::MaybeXS, Kwalify,
+List::SomeUtils, Perl6::Slurp, Template (part of Template Toolkit), and
+YAML::XS, all of which are available from CPAN.
 
 =head1 DESCRIPTION
 
@@ -285,7 +286,7 @@ Russ Allbery <rra@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2018-2019 Russ Allbery <rra@cpan.org>
+Copyright 2018-2021 Russ Allbery <rra@cpan.org>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -307,10 +308,10 @@ SOFTWARE.
 
 =head1 SEE ALSO
 
-L<App::DocKnot::Generate>, L<docknot(1)>
+L<docknot(1)>
 
 This module is part of the App-DocKnot distribution.  The current version of
-App::DocKnot is available from CPAN, or directly from its web site at
+DocKnot is available from CPAN, or directly from its web site at
 L<https://www.eyrie.org/~eagle/software/docknot/>.
 
 =cut
