@@ -10,7 +10,7 @@
 # Modules and declarations
 ##############################################################################
 
-package App::DocKnot::Generate 3.05;
+package App::DocKnot::Generate 4.01;
 
 use 5.024;
 use autodie;
@@ -19,6 +19,7 @@ use warnings;
 
 use App::DocKnot::Config;
 use Carp qw(croak);
+use Encode qw(encode);
 use Template;
 use Text::Wrap qw(wrap);
 
@@ -41,8 +42,6 @@ my %DEFAULT_OUTPUT = (
 # the line.  The returned code will take a line of text and return that line
 # with leading whitespace added as required.
 #
-# $self - The App::DocKnot::Generate object
-#
 # Returns: Code reference to a closure that uses $self->{width} for width
 sub _code_for_center {
     my ($self) = @_;
@@ -64,7 +63,6 @@ sub _code_for_center {
 # They will be wrapped with a four-space outdent and kept within
 # $self->{width} columns.
 #
-# $self           - The App::DocKnot::Generate object
 # $copyrights_ref - A reference to a list of anonymous hashes, each with keys:
 #   holder - The copyright holder for that copyright
 #   years  - The years of that copyright
@@ -114,8 +112,6 @@ sub _code_for_copyright {
 # doesn't use any configuration.  It takes the indentation and an optional
 # prefix to put at the start of each line.
 #
-# $self - The App::DocKnot::Generate object
-#
 # Returns: Code reference to a closure
 sub _code_for_indent {
     my ($self) = @_;
@@ -136,8 +132,6 @@ sub _code_for_indent {
 # be influenced by App::DocKnot configuration in the future, but it currently
 # doesn't use any configuration.
 #
-# $self - The App::DocKnot::Generate object
-#
 # Returns: Code reference to a closure that takes a block of text and returns
 #          the converted text
 sub _code_for_to_text {
@@ -209,8 +203,6 @@ sub _code_for_to_text {
 # be influenced by App::DocKnot configuration in the future, but it currently
 # doesn't use any configuration.
 #
-# $self - The App::DocKnot::Generate object
-#
 # Returns: Code reference to a closure that takes a block of text and returns
 #          the converted thread
 sub _code_for_to_thread {
@@ -310,56 +302,77 @@ sub _code_for_to_thread {
 # four spaces and consistently on each line, remove the indentation and then
 # add it back in while wrapping the text.
 #
-# $self      - The App::DocKnot::Generate object
-# $paragraph - A paragraph of text to wrap
+# $para        - A paragraph of text to wrap
+# $options_ref - Options to controll the wrapping
+#   ignore_indent - Ignore indentation when choosing whether to wrap
 #
 # Returns: The wrapped paragraph
 sub _wrap_paragraph {
-    my ($self, $paragraph) = @_;
-    my ($indent) = ($paragraph =~ m{ \A ([ ]*) \S }xms);
+    my ($self, $para, $options_ref) = @_;
+    $options_ref //= {};
+    my ($indent) = ($para =~ m{ \A ([ ]*) \S }xms);
 
-    # If the indent is longer than four characters, leave it alone.
-    if (length($indent) > 4) {
-        return $paragraph;
+    # If the indent is longer than five characters and the ignore indent
+    # option is not set, leave it alone.  Allow an indent of five characters
+    # since it may be a continuation of a numbered list entry.
+    if (length($indent) > 5 && !$options_ref->{ignore_indent}) {
+        return $para;
     }
 
     # If this looks like thread commands or URLs, leave it alone.
-    if ($paragraph =~ m{ \A \s* (?: \\ | \[\d+\] ) }xms) {
-        return $paragraph;
+    if ($para =~ m{ \A \s* (?: \\ | \[\d+\] ) }xms) {
+        return $para;
     }
 
     # If this starts with a bullet, strip the bullet off, wrap the paragraph,
     # and then add it back in.
-    if ($paragraph =~ s{ \A (\s*) [*] (\s+) }{$1 $2}xms) {
+    if ($para =~ s{ \A (\s*) [*] (\s+) }{$1 $2}xms) {
         my $offset = length($1);
-        $paragraph = $self->_wrap_paragraph($paragraph);
-        substr($paragraph, $offset, 1, q{*});
-        return $paragraph;
+        $para = $self->_wrap_paragraph($para, { ignore_indent => 1 });
+        substr($para, $offset, 1, q{*});
+        return $para;
     }
 
-    # If this looks like a Markdown block quote leave it alone, but strip
-    # trailing whitespace.
-    if ($paragraph =~ m{ \A \s* > \s }xms) {
-        $paragraph =~ s{ [ ]+ \n }{\n}xmsg;
-        return $paragraph;
+    # If this starts with a number, strip the number off, wrap the paragraph,
+    # and then add it back in.
+    if ($para =~ s{\A (\s*) (\d+[.]) (\s+)}{$1 . q{ } x length($2) . $3}xmse) {
+        my $offset = length($1);
+        my $number = $2;
+        $para = $self->_wrap_paragraph($para, { ignore_indent => 1 });
+        substr($para, $offset, length($number), $number);
+        return $para;
     }
 
+    # If this looks like a Markdown block quote, strip trailing whitespace,
+    # remove the leading indentation marks, wrap the paragraph, and then put
+    # them back.
+    ## no critic (RegularExpressions::ProhibitCaptureWithoutTest)
+    if ($para =~ m{ \A (\s*) > \s }xms) {
+        $para =~ s{ [ ]+ \n }{\n}xmsg;
+        $para =~ s{ ^ (\s*) > (\s) }{$1 $2}xmsg;
+        my $offset = length($1);
+        $para = $self->_wrap_paragraph($para, { ignore_indent => 1 });
+        $para =~ s{ ^ (\s{$offset}) \s }{$1>}xmsg;
+        return $para;
+    }
+    ## use critic
+
     # If this looks like a bunch of short lines, leave it alone.
-    if ($paragraph =~ m{ \A (?: \Q$indent\E [^\n]{1,45} \n ){3,} }xms) {
-        return $paragraph;
+    if ($para =~ m{ \A (?: \Q$indent\E [^\n]{1,45} \n ){3,} }xms) {
+        return $para;
     }
 
     # If this paragraph is not consistently indented, leave it alone.
-    if ($paragraph !~ m{ \A (?: \Q$indent\E \S[^\n]+ \n )+ \z }xms) {
-        return $paragraph;
+    if ($para !~ m{ \A (?: \Q$indent\E \S[^\n]+ \n )+ \z }xms) {
+        return $para;
     }
 
     # Strip the indent from each line.
-    $paragraph =~ s{ (?: \A | (?<=\n) ) \Q$indent\E }{}xmsg;
+    $para =~ s{ (?: \A | (?<=\n) ) \Q$indent\E }{}xmsg;
 
     # Remove any existing newlines, preserving two spaces after periods.
-    $paragraph =~ s{ [.] ([)\"]?) \n (\S) }{.$1  $2}xmsg;
-    $paragraph =~ s{ \n(\S) }{ $1}xmsg;
+    $para =~ s{ [.] ([)\"]?) \n (\S) }{.$1  $2}xmsg;
+    $para =~ s{ \n(\S) }{ $1}xmsg;
 
     # Force locally correct configuration of Text::Wrap.
     local $Text::Wrap::break    = qr{\s+}xms;
@@ -368,21 +381,20 @@ sub _wrap_paragraph {
     local $Text::Wrap::unexpand = 0;
 
     # Do the wrapping.  This modifies @paragraphs in place.
-    $paragraph = wrap($indent, $indent, $paragraph);
+    $para = wrap($indent, $indent, $para);
 
     # Strip any trailing whitespace, since some gets left behind after periods
     # by Text::Wrap.
-    $paragraph =~ s{ [ ]+ \n }{\n}xmsg;
+    $para =~ s{ [ ]+ \n }{\n}xmsg;
 
     # All done.
-    return $paragraph;
+    return $para;
 }
 
 # Word-wrap a block of text.  This requires some annoying heuristics, but the
 # alternative is to try to get the template to always produce correctly
 # wrapped results, which is far harder.
 #
-# $self - The App::DocKnot::Generate object
 # $text - The text to wrap
 #
 # Returns: The wrapped text
@@ -416,7 +428,6 @@ sub _wrap {
 # Create a new App::DocKnot::Generate object, which will be used for
 # subsequent calls.
 #
-# $class - Class of object to create
 # $args  - Anonymous hash of arguments with the following keys:
 #   metadata - Path to the directory containing package metadata
 #   width    - Line length at which to wrap output files
@@ -444,7 +455,6 @@ sub new {
 
 # Generate a documentation file from the package metadata.
 #
-# $self     - The App::DocKnot::Generate object
 # $template - Name of the documentation template (using Template Toolkit)
 #
 # Returns: The generated documentation as a string
@@ -483,8 +493,6 @@ sub generate {
 # Generate all package documentation from the package metadata.  Only
 # generates the output for templates with a default output file.
 #
-# $self - The App::DocKnot::Generate object
-#
 # Returns: undef
 #  Throws: autodie exception on failure to read metadata or write the output
 #          Text exception on Template Toolkit failures
@@ -499,7 +507,6 @@ sub generate_all {
 
 # Generate a documentation file from the package metadata.
 #
-# $self     - The App::DocKnot::Generate object
 # $template - Name of the documentation template
 # $output   - Output file name (undef to use the default)
 #
@@ -518,7 +525,7 @@ sub generate_output {
 
     # Generate the output.
     open(my $outfh, '>', $output);
-    print {$outfh} $self->generate($template)
+    print {$outfh} encode('utf-8', $self->generate($template))
       or croak("cannot write to $output: $!");
     close($outfh);
     return;
@@ -533,7 +540,7 @@ __END__
 
 =for stopwords
 Allbery DocKnot MERCHANTABILITY NONINFRINGEMENT XDG sublicense JSON CPAN
-ARGS
+ARGS Kwalify
 
 =head1 NAME
 
@@ -542,7 +549,8 @@ App::DocKnot::Generate - Generate documentation from package metadata
 =head1 SYNOPSIS
 
     use App::DocKnot::Generate;
-    my $docknot = App::DocKnot::Generate->new({ metadata => 'docs/metadata' });
+    my $docknot
+      = App::DocKnot::Generate->new({ metadata => 'docs/docknot.yaml' });
     my $readme = $docknot->generate('readme');
     my $index = $docknot->generate('thread');
     $docknot->generate_output('readme');
@@ -550,9 +558,9 @@ App::DocKnot::Generate - Generate documentation from package metadata
 
 =head1 REQUIREMENTS
 
-Perl 5.24 or later and the modules File::BaseDir, File::ShareDir, JSON,
-Perl6::Slurp, and Template (part of Template Toolkit), all of which are
-available from CPAN.
+Perl 5.24 or later and the modules File::BaseDir, File::ShareDir, Kwalify,
+Template (part of Template Toolkit), and YAML::XS, all of which are available
+from CPAN.
 
 =head1 DESCRIPTION
 
@@ -602,7 +610,7 @@ following keys:
 =item metadata
 
 The path to the directory containing metadata for a package.  Default:
-F<docs/metadata> relative to the current directory.
+F<docs/docknot.yaml> relative to the current directory.
 
 =item width
 
@@ -651,7 +659,7 @@ Russ Allbery <rra@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2020 Russ Allbery <rra@cpan.org>
+Copyright 2013-2021 Russ Allbery <rra@cpan.org>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -673,10 +681,10 @@ SOFTWARE.
 
 =head1 SEE ALSO
 
-L<docknot(1)>
+L<docknot(1)>, L<App::DocKnot::Config>
 
 This module is part of the App-DocKnot distribution.  The current version of
-App::DocKnot is available from CPAN, or directly from its web site at
+DocKnot is available from CPAN, or directly from its web site at
 L<https://www.eyrie.org/~eagle/software/docknot/>.
 
 =cut
